==> jc-1.4.0.tar.gz: soot/jimple/parser/node/APublicModifier.h <==
// public final class soot.jimple.parser.node.APublicModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 786357a0fed2a861 soot_jimple_parser_node_APublicModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_APublicModifier_H_
#define _JC_soot_jimple_parser_node_APublicModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TPublic$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_APublicModifier$sub_refs	_jc_soot_jimple_parser_node_APublicModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_APublicModifier$sub_nonrefs	_jc_soot_jimple_parser_node_APublicModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_APublicModifier$refs	_jc_soot_jimple_parser_node_APublicModifier$refs;
typedef struct _jc_soot_jimple_parser_node_APublicModifier$nonrefs	_jc_soot_jimple_parser_node_APublicModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_APublicModifier$object	_jc_soot_jimple_parser_node_APublicModifier$object;

typedef const struct _jc_soot_jimple_parser_node_APublicModifier$vmethods	_jc_soot_jimple_parser_node_APublicModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_APublicModifier$vtable	_jc_soot_jimple_parser_node_APublicModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_APublicModifier$vtype	_jc_soot_jimple_parser_node_APublicModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_APublicModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *);
extern void _jc_soot_jimple_parser_node_APublicModifier$method$_init$ac75b72581b6317c(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_TPublic$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_APublicModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_APublicModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *);
extern struct _jc_soot_jimple_parser_node_TPublic$object *_jc_soot_jimple_parser_node_APublicModifier$method$getPublic$ea73774225fabfad(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *);
extern void _jc_soot_jimple_parser_node_APublicModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_APublicModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_APublicModifier$method$setPublic$911b9a54b9033ec4(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_TPublic$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_APublicModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$getPublic$ea73774225fabfad;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$setPublic$911b9a54b9033ec4;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_APublicModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *);
	struct _jc_soot_jimple_parser_node_TPublic$object	*(*getPublic$ea73774225fabfad)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPublic$911b9a54b9033ec4)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_TPublic$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_APublicModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_APublicModifier$vmethods	soot_jimple_parser_node_APublicModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_APublicModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_APublicModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APublicModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TPublic$object	*__5fpublic__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_APublicModifier$refs {
    _jc_soot_jimple_parser_node_APublicModifier$sub_refs	soot_jimple_parser_node_APublicModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APublicModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_APublicModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_APublicModifier$sub_nonrefs	soot_jimple_parser_node_APublicModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_APublicModifier$object {
	_jc_soot_jimple_parser_node_APublicModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_APublicModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_APublicModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_APublicModifier$vtype _jc_soot_jimple_parser_node_APublicModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_APublicModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_APublicModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_APublicModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/APublicModifier.h <==
// public final class soot.jimple.parser.node.APublicModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 786357a0fed2a861 soot_jimple_parser_node_APublicModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_APublicModifier_H_
#define _JC_soot_jimple_parser_node_APublicModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TPublic$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_APublicModifier$sub_refs	_jc_soot_jimple_parser_node_APublicModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_APublicModifier$sub_nonrefs	_jc_soot_jimple_parser_node_APublicModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_APublicModifier$refs	_jc_soot_jimple_parser_node_APublicModifier$refs;
typedef struct _jc_soot_jimple_parser_node_APublicModifier$nonrefs	_jc_soot_jimple_parser_node_APublicModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_APublicModifier$object	_jc_soot_jimple_parser_node_APublicModifier$object;

typedef const struct _jc_soot_jimple_parser_node_APublicModifier$vmethods	_jc_soot_jimple_parser_node_APublicModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_APublicModifier$vtable	_jc_soot_jimple_parser_node_APublicModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_APublicModifier$vtype	_jc_soot_jimple_parser_node_APublicModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_APublicModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APublicModifier$method$_init$ac75b72581b6317c(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_TPublic$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_APublicModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_APublicModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TPublic$object *_jc_soot_jimple_parser_node_APublicModifier$method$getPublic$ea73774225fabfad(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APublicModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APublicModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APublicModifier$method$setPublic$911b9a54b9033ec4(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_TPublic$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_APublicModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$getPublic$ea73774225fabfad;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$setPublic$911b9a54b9033ec4;
extern _jc_method _jc_soot_jimple_parser_node_APublicModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_APublicModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TPublic$object	*(*getPublic$ea73774225fabfad)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPublic$911b9a54b9033ec4)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *, struct _jc_soot_jimple_parser_node_TPublic$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_APublicModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_APublicModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_APublicModifier$vmethods	soot_jimple_parser_node_APublicModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_APublicModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_APublicModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APublicModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TPublic$object	*__5fpublic__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_APublicModifier$refs {
    _jc_soot_jimple_parser_node_APublicModifier$sub_refs	soot_jimple_parser_node_APublicModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APublicModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_APublicModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_APublicModifier$sub_nonrefs	soot_jimple_parser_node_APublicModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_APublicModifier$object {
	_jc_soot_jimple_parser_node_APublicModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_APublicModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_APublicModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_APublicModifier$vtype _jc_soot_jimple_parser_node_APublicModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_APublicModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_APublicModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_APublicModifier_H_ */
